@@ -152,17 +152,16 @@ class Gnuplot(object):
         log: If show the gnuplot log
         **kwargs: the flag that need to be set. You can also set them in the set() function.
         '''
+
+        self.isMultiplot = False
         self.gnuplot = subprocess.Popen(['gnuplot','-p'], shell=True, stdin=subprocess.PIPE)
         # forward write and flush methods:
         self.write = self.gnuplot.stdin.write
         self.flush = self.gnuplot.stdin.flush
         self.log = log
 
-        for v in args:
-            self.cmd('set %s' %(v))
-        for k,v in kwargs.items():
-            #self[k] = v
-            self.cmd('set %s %s' %(k, v))
+        self.set(*args)
+        self.set(**kwargs)
 
     def __del__(self):
         #print("%s:%d" %(os.path.basename(__file__), sys._getframe().f_lineno))
@@ -222,12 +221,23 @@ class Gnuplot(object):
         '''
         for v in args:
             self.cmd('set %s' %(v))
+        if 'multiplot' in args:
+            #print("Enter Multiplot mode.")
+            self.isMultiplot = True
+
         for k,v in kwargs.items():
+            if (k == 'multiplot'):
+                if (v is not None):
+                    #print("Enter Multiplot mode.")
+                    self.isMultiplot = True
+                else:
+                    #print("Exit Multiplot mode.")
+                    self.isMultiplot = False
             if isinstance(v, list):
                 for i in v:
                     self.cmd('set %s %s' %(k, i))
             else:
-                if (v == None):
+                if (v is None):
                     self.cmd('unset %s' %(k))
                 else:
                     self.cmd('set %s %s' %(k, v))
@@ -254,6 +264,10 @@ class Gnuplot(object):
         cmd = c.rstrip(',')
         self.cmd(cmd + '\n')
 
+        # unset the label if it's in multiplot mode.
+        if self.isMultiplot:
+            g.unset('for [i=1:200] label i')
+
     def plot_data(self, data, *items, **kwargs):
         '''
         data: The data that need to be plotted. It's either the string of list
@@ -277,6 +291,10 @@ class Gnuplot(object):
         cmd = c.rstrip(",\\\r\n")
         self.cmd(cmd + '\n')
 
+        # unset the label if it's in multiplot mode.
+        if self.isMultiplot:
+            self.unset('for [i=1:200] label i')
+
     def splot_data(self, data, *items, **kwargs):
         '''
         data: The data that need to be plotted. It's either the string of list
@@ -300,6 +318,10 @@ class Gnuplot(object):
         cmd = c.rstrip(',')
         self.cmd(cmd + '\n')
 
+        # unset the label if it's in multiplot mode.
+        if self.isMultiplot:
+            g.unset('for [i=1:200] label i')
+
     def splot(self, *items, **kwargs):
         self.set(**kwargs)
         c = 'splot'
@@ -308,6 +330,10 @@ class Gnuplot(object):
         cmd = c.rstrip(',')
         self.cmd(cmd + '\n')
 
+        # unset the label if it's in multiplot mode.
+        if self.isMultiplot:
+            g.unset('for [i=1:200] label i')
+
 
     def evaluate(self, cmd):
         self.cmd('evaluate %s' %(cmd))
